Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(582)

Unified Diff: media/capture/screen_capture_device_core.h

Issue 1162863003: Move ContentVideoCaptureDeviceCore from src/content to src/media (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/capture/feedback_signal_accumulator_unittest.cc ('k') | media/capture/screen_capture_device_core.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/capture/screen_capture_device_core.h
diff --git a/content/browser/media/capture/content_video_capture_device_core.h b/media/capture/screen_capture_device_core.h
similarity index 31%
copy from content/browser/media/capture/content_video_capture_device_core.h
copy to media/capture/screen_capture_device_core.h
index 0590e5157b101f5218e4a39c5acb874cd6de36ec..86c1fc57fe370180e8e01c868671014528fa8b47 100644
--- a/content/browser/media/capture/content_video_capture_device_core.h
+++ b/media/capture/screen_capture_device_core.h
@@ -2,123 +2,37 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_BROWSER_MEDIA_CAPTURE_CONTENT_VIDEO_CAPTURE_DEVICE_CORE_H_
-#define CONTENT_BROWSER_MEDIA_CAPTURE_CONTENT_VIDEO_CAPTURE_DEVICE_CORE_H_
+#ifndef MEDIA_CAPTURE_SCREEN_CAPTURE_DEVICE_CORE_H_
+#define MEDIA_CAPTURE_SCREEN_CAPTURE_DEVICE_CORE_H_
#include <string>
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
-#include "base/threading/thread.h"
#include "base/threading/thread_checker.h"
-#include "content/browser/media/capture/capture_resolution_chooser.h"
-#include "content/browser/media/capture/video_capture_oracle.h"
-#include "content/common/content_export.h"
-#include "media/base/video_frame.h"
+#include "media/base/media_export.h"
+#include "media/capture/thread_safe_capture_oracle.h"
#include "media/video/capture/video_capture_device.h"
namespace media {
-struct VideoCaptureParams;
-class VideoFrame;
-} // namespace media
-
-namespace content {
-
-class VideoCaptureMachine;
-
-// Thread-safe, refcounted proxy to the VideoCaptureOracle. This proxy wraps
-// the VideoCaptureOracle, which decides which frames to capture, and a
-// VideoCaptureDevice::Client, which allocates and receives the captured
-// frames, in a lock to synchronize state between the two.
-class ThreadSafeCaptureOracle
- : public base::RefCountedThreadSafe<ThreadSafeCaptureOracle> {
- public:
- ThreadSafeCaptureOracle(scoped_ptr<media::VideoCaptureDevice::Client> client,
- const media::VideoCaptureParams& params);
-
- // Called when a captured frame is available or an error has occurred.
- // If |success| is true then |frame| is valid and |timestamp| indicates when
- // the frame was painted.
- // If |success| is false, all other parameters are invalid.
- typedef base::Callback<void(const scoped_refptr<media::VideoFrame>& frame,
- base::TimeTicks timestamp,
- bool success)> CaptureFrameCallback;
-
- bool ObserveEventAndDecideCapture(VideoCaptureOracle::Event event,
- const gfx::Rect& damage_rect,
- base::TimeTicks event_time,
- scoped_refptr<media::VideoFrame>* storage,
- CaptureFrameCallback* callback);
-
- base::TimeDelta min_capture_period() const {
- return oracle_.min_capture_period();
- }
- gfx::Size max_frame_size() const {
- return params_.requested_format.frame_size;
- }
-
- // Returns the current capture resolution.
- gfx::Size GetCaptureSize() const;
-
- // Updates capture resolution based on the supplied source size and the
- // maximum frame size.
- void UpdateCaptureSize(const gfx::Size& source_size);
-
- // Stop new captures from happening (but doesn't forget the client).
- void Stop();
-
- // Signal an error to the client.
- void ReportError(const std::string& reason);
+struct VideoCaptureParams;
- private:
- friend class base::RefCountedThreadSafe<ThreadSafeCaptureOracle>;
- virtual ~ThreadSafeCaptureOracle();
-
- // Callback invoked on completion of all captures.
- void DidCaptureFrame(
- int frame_number,
- scoped_ptr<media::VideoCaptureDevice::Client::Buffer> buffer,
- base::TimeTicks capture_begin_time,
- base::TimeDelta estimated_frame_duration,
- const scoped_refptr<media::VideoFrame>& frame,
- base::TimeTicks timestamp,
- bool success);
-
- // Callback invoked once all consumers have finished with a delivered video
- // frame. Consumer feedback signals are scanned from the frame's |metadata|.
- void DidConsumeFrame(int frame_number,
- const media::VideoFrameMetadata* metadata);
-
- // Protects everything below it.
- mutable base::Lock lock_;
-
- // Recipient of our capture activity.
- scoped_ptr<media::VideoCaptureDevice::Client> client_;
-
- // Makes the decision to capture a frame.
- VideoCaptureOracle oracle_;
-
- // The video capture parameters used to construct the oracle proxy.
- const media::VideoCaptureParams params_;
-
- // Determines video capture frame sizes.
- CaptureResolutionChooser resolution_chooser_;
-};
+class ThreadSafeCaptureOracle;
-// Keeps track of the video capture source frames and executes copying on the
-// UI BrowserThread.
+// Keeps track of the video capture source frames and executes copying.
class VideoCaptureMachine {
public:
VideoCaptureMachine() {}
virtual ~VideoCaptureMachine() {}
- // Starts capturing. Returns true if succeeded.
- // Must be run on the UI BrowserThread.
- virtual bool Start(const scoped_refptr<ThreadSafeCaptureOracle>& oracle_proxy,
- const media::VideoCaptureParams& params) = 0;
+ // Starts capturing.
+ // |callback| is invoked with true if succeeded. Otherwise, with false.
+ virtual void Start(const scoped_refptr<ThreadSafeCaptureOracle>& oracle_proxy,
+ const VideoCaptureParams& params,
+ const base::Callback<void(bool)> callback) = 0;
- // Stops capturing. Must be run on the UI BrowserThread.
+ // Stops capturing.
// |callback| is invoked after the capturing has stopped.
virtual void Stop(const base::Closure& callback) = 0;
@@ -132,20 +46,20 @@ class VideoCaptureMachine {
// DesktopCaptureDeviceAura allows safe destruction without needing to block any
// threads, as well as code sharing.
//
// ContentVideoCaptureDeviceCore manages a simple state machine and the pipeline
// (see notes at top of this file). It times the start of successive captures
// and facilitates the processing of each through the stages of the
// pipeline.
-class CONTENT_EXPORT ContentVideoCaptureDeviceCore
- : public base::SupportsWeakPtr<ContentVideoCaptureDeviceCore> {
+class MEDIA_EXPORT ScreenCaptureDeviceCore
+ : public base::SupportsWeakPtr<ScreenCaptureDeviceCore> {
public:
- ContentVideoCaptureDeviceCore(
+ ScreenCaptureDeviceCore(
scoped_ptr<VideoCaptureMachine> capture_machine);
- virtual ~ContentVideoCaptureDeviceCore();
+ virtual ~ScreenCaptureDeviceCore();
- // Asynchronous requests to change ContentVideoCaptureDeviceCore state.
- void AllocateAndStart(const media::VideoCaptureParams& params,
- scoped_ptr<media::VideoCaptureDevice::Client> client);
+ // Asynchronous requests to change ScreenCaptureDeviceCore state.
+ void AllocateAndStart(const VideoCaptureParams& params,
+ scoped_ptr<VideoCaptureDevice::Client> client);
void StopAndDeAllocate();
private:
@@ -171,9 +85,9 @@ class CONTENT_EXPORT ContentVideoCaptureDeviceCore
// Current lifecycle state.
State state_;
- // Tracks the CaptureMachine that's doing work on our behalf on the UI thread.
- // This value should never be dereferenced by this class, other than to
- // create and destroy it on the UI thread.
+ // Tracks the CaptureMachine that's doing work on our behalf
+ // on the device thread or UI thread.
+ // This value should never be dereferenced by this class.
scoped_ptr<VideoCaptureMachine> capture_machine_;
// Our thread-safe capture oracle which serves as the gateway to the video
@@ -181,10 +95,10 @@ class CONTENT_EXPORT ContentVideoCaptureDeviceCore
// component of the system with direct access to |client_|.
scoped_refptr<ThreadSafeCaptureOracle> oracle_proxy_;
- DISALLOW_COPY_AND_ASSIGN(ContentVideoCaptureDeviceCore);
+ DISALLOW_COPY_AND_ASSIGN(ScreenCaptureDeviceCore);
};
-} // namespace content
+} // namespace media
-#endif // CONTENT_BROWSER_MEDIA_CAPTURE_CONTENT_VIDEO_CAPTURE_DEVICE_CORE_H_
+#endif // MEDIA_CAPTURE_SCREEN_CAPTURE_DEVICE_CORE_H_
« no previous file with comments | « media/capture/feedback_signal_accumulator_unittest.cc ('k') | media/capture/screen_capture_device_core.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -132,20 +46,20 @@ class VideoCaptureMachine {
// threads, as well as code sharing.
//
-// ContentVideoCaptureDeviceCore manages a simple state machine and the pipeline
+// ScreenCaptureDeviceCore manages a simple state machine and the pipeline
// (see notes at top of this file). It times the start of successive captures
// and facilitates the processing of each through the stages of the
This is Rietveld 408576698